
Full details on how to build/run/use this application can be found in the [Getting Started section of the SMV User Guide](https://github.com/TresAmigosSD/SMV/blob/master/docs/user/getting_started.md)

# Run App in batch
```shell
$ smv-run --run-app
```

# Run App in Spark Shell
```shell
$ smv-pyshell
```
